[_admonition_block]: https://github.com/facelessuser/pymdown-extensions/blob/feature/directives/pymdownx/blocks/admonition.py "Source"
[_arithmatex]: https://github.com/facelessuser/pymdown-extensions/blob/master/pymdownx/arithmatex.py "Source"
[_b64]: https://github.com/facelessuser/pymdown-extensions/blob/master/pymdownx/b64.py "Source"
[_betterem]: https://github.com/facelessuser/pymdown-extensions/blob/master/pymdownx/betterem.py "Source"
[_blocks]: https://github.com/facelessuser/pymdown-extensions/blob/feature/directives/pymdownx/blocks/__init__.py "Source"
[_caret]: https://github.com/facelessuser/pymdown-extensions/blob/master/pymdownx/caret.py "Source"
[_critic]: https://github.com/facelessuser/pymdown-extensions/blob/master/pymdownx/critic.py "Source"
[_definition_block]: https://github.com/facelessuser/pymdown-extensions/blob/feature/directives/pymdownx/blocks/definition.py "Source"
[_details]: https://github.com/facelessuser/pymdown-extensions/blob/master/pymdownx/details.py "Source"
[_details_block]: https://github.com/facelessuser/pymdown-extensions/blob/feature/directives/pymdownx/blocks/details.py "Source"
[_emoji]: https://github.com/facelessuser/pymdown-extensions/blob/master/pymdownx/emoji.py "Source"
[_escapeall]: https://github.com/facelessuser/pymdown-extensions/blob/master/pymdownx/escapeall.py "Source"
[_extra]: https://github.com/facelessuser/pymdown-extensions/blob/master/pymdownx/extra.py "Source"
[_fancylists]: https://github.com/facelessuser/pymdown-extensions/blob/master/pymdownx/fancylists.py "Source"
[_highlight]: https://github.com/facelessuser/pymdown-extensions/blob/master/pymdownx/highlight.py "Source"
[_html_block]: https://github.com/facelessuser/pymdown-extensions/blob/feature/directives/pymdownx/blocks/html.py "Source"
[_inlinehilite]: https://github.com/facelessuser/pymdown-extensions/blob/master/pymdownx/inlinehilite.py "Source"
[_keys]: https://github.com/facelessuser/pymdown-extensions/blob/master/pymdownx/keys.py "Source"
[_magiclink]: https://github.com/facelessuser/pymdown-extensions/blob/master/pymdownx/magiclink.py "Source"
[_mark]: https://github.com/facelessuser/pymdown-extensions/blob/master/pymdownx/mark.py "Source"
[_pathconverter]: https://github.com/facelessuser/pymdown-extensions/blob/master/pymdownx/pathconverter.py "Source"
[_progressbar]: https://github.com/facelessuser/pymdown-extensions/blob/master/pymdownx/progressbar.py "Source"
[_saneheaders]: https://github.com/facelessuser/pymdown-extensions/blob/master/pymdownx/saneheaders.py "Source"
[_slugs]: https://github.com/facelessuser/pymdown-extensions/blob/master/pymdownx/slugs.py "Source"
[_smartsymbols]: https://github.com/facelessuser/pymdown-extensions/blob/master/pymdownx/smartsymbols.py "Source"
[_snippets]: https://github.com/facelessuser/pymdown-extensions/blob/master/pymdownx/snippets.py "Source"
[_striphtml]: https://github.com/facelessuser/pymdown-extensions/blob/master/pymdownx/striphtml.py "Source"
[_superfences]: https://github.com/facelessuser/pymdown-extensions/blob/master/pymdownx/superfences.py "Source"
[_tab_block]: https://github.com/facelessuser/pymdown-extensions/blob/feature/directives/pymdownx/blocks/tab.py "Source"
[_tabbed]: https://github.com/facelessuser/pymdown-extensions/blob/master/pymdownx/tabbed.py "Source"
[_tasklist]: https://github.com/facelessuser/pymdown-extensions/blob/master/pymdownx/tasklist.py "Source"
[_tilde]: https://github.com/facelessuser/pymdown-extensions/blob/master/pymdownx/tilde.py "Source"
[abbreviations]: https://python-markdown.github.io/extensions/abbreviations/
[admonition]: https://python-markdown.github.io/extensions/admonition/
[aspell]: http://aspell.net/
[atomic]: https://python-markdown.github.io/extensions/api/#working_with_et
[attr-list]: https://python-markdown.github.io/extensions/attr_list/
[bleach]: https://pypi.python.org/pypi/bleach
[codehilite]: https://python-markdown.github.io/extensions/code_hilite/
[coverage]: https://coverage.readthedocs.io
[critic-markup]: http://criticmarkup.com/
[def-list]: https://python-markdown.github.io/extensions/definition_lists/
[emojione-awesome-css]: https://github.com/Ranks/emojione/blob/master/extras/css/emojione-awesome.css
[emojione-index]: https://github.com/facelessuser/pymdown-extensions/blob/master/pymdownx/emoji1_db.py
[emojione-sprites-svg]: https://github.com/Ranks/emojione/blob/v2.2.7/assets/sprites/emojione.sprites.svg
[emojione]: https://github.com/Ranks/emojione
[etree]: https://docs.python.org/3/library/xml.etree.elementtree.html
[flake8-docstrings]: https://pypi.python.org/pypi/flake8-docstrings
[flake8]: https://pypi.python.org/pypi/flake8
[footnotes]: https://python-markdown.github.io/extensions/footnotes/
[gemoji-index]: https://github.com/facelessuser/pymdown-extensions/blob/master/pymdownx/gemoji_db.py
[gemoji]: https://github.com/github/gemoji
[github-api-emoji]: https://developer.github.com/v3/emojis/
[github-api-oauth]: https://developer.github.com/v3/oauth/
[highlightjs]: https://highlightjs.org/
[katex]: https://github.com/Khan/KaTeX
[magiclink-icons]: https://github.com/facelessuser/pymdown-extensions/blob/master/docs/src/scss/extensions/_magiclink.scss
[mathjax]: http://www.mathjax.org/
[md-in-html]: https://python-markdown.github.io/extensions/md_in_html/
[mermaid-config]: https://github.com/facelessuser/pymdown-extensions/blob/master/docs/src/markdown/_snippets/uml.txt
[mermaid-loader]: https://github.com/facelessuser/pymdown-extensions/blob/master/docs/src/js/uml.js
[mermaid-style]: https://github.com/facelessuser/pymdown-extensions/blob/master/docs/src/scss/js/_mermaid.scss
[mermaid]: https://mermaid-js.github.io/mermaid/#/
[mkdocs-config]: https://github.com/facelessuser/pymdown-extensions/blob/master/mkdocs.yml
[mkdocs-material]: https://github.com/squidfunk/mkdocs-material
[mkdocs]: https://github.com/mkdocs/mkdocs
[nested-markdown]: https://python-markdown.github.io/extensions/extra/#nested-markdown-inside-html-blocks
[nl2br]: https://python-markdown.github.io/extensions/nl2br/
[octicons]: https://octicons.github.com/
[onready-event]: https://github.com/facelessuser/pymdown-extensions/blob/master/docs/src/js/extra-uml.js
[pandoc-lists]: https://pandoc.org/chunkedhtml-demo/8.7-lists.html
[pep8-naming]: https://pypi.python.org/pypi/pep8-naming
[pygments]: http://pygments.org/
[pymdown-styles]: https://github.com/facelessuser/pymdown-styles/tree/master/pymdown_styles
[pytest]: http://doc.pytest.org/en/latest/
[python-markdown]: https://github.com/Python-Markdown/markdown
[pyyaml]: https://github.com/yaml/pyyaml
[requests]: https://pypi.python.org/pypi/requests/
[stash]: https://python-markdown.github.io/extensions/api/#working_with_raw_html
[tables]: https://python-markdown.github.io/extensions/tables/
[toc]: https://python-markdown.github.io/extensions/toc/
[tox]: https://pypi.python.org/pypi/tox
[twemoji-index]: https://github.com/facelessuser/pymdown-extensions/blob/master/pymdownx/twemoji_db.py
[twemoji]: https://github.com/twitter/twemoji
[unicode-norm]: http://unicode.org/reports/tr15/#Norm_Forms
